@@ -54,6 +54,8 @@ CyclicCoordinateDescent::CyclicCoordinateDescent(
 	noiseLevel = NOISY;
 	initialBound = 2.0;
 
+	priorType = priors::NONE;
+
 	init(hXI.getHasOffsetCovariate());
 }
 
@@ -89,6 +91,8 @@ CyclicCoordinateDescent::CyclicCoordinateDescent(const CyclicCoordinateDescent&
 	noiseLevel = copy.noiseLevel;
 	initialBound = copy.initialBound;
 
+	priorType = copy.priorType;
+
 	init(hXI.getHasOffsetCovariate());
 
 	if (copy.hWeights.size() > 0) {
