@@ -14,11 +14,11 @@ namespace bsccs {
 
 class HierarchyAutoSearchCrossValidationDriver : public AutoSearchCrossValidationDriver {
 public:
-	HierarchyAutoSearchCrossValidationDriver(const ModelData& _modelData,
+	HierarchyAutoSearchCrossValidationDriver(const AbstractModelData& _modelData,
 			const CCDArguments& arguments,
 			loggers::ProgressLoggerPtr _logger,
-			loggers::ErrorHandlerPtr _error,			
-			std::vector<real>* wtsExclude = NULL);
+			loggers::ErrorHandlerPtr _error,
+			std::vector<double>* wtsExclude = NULL);
 
 	virtual ~HierarchyAutoSearchCrossValidationDriver();
 
